@@ -10,7 +10,7 @@ use Hash::Merge();
 
 use experimental 'postderef';
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub new {
     my($class, %args) = @_;
@@ -205,11 +205,11 @@ Optional. If set to a true value Config::FromHash will C<die> if any config file
 
 =head1 METHODS
 
-B<C$self-><get($path)>>
+B<C<$self-E<gt>get($path)>>
 
 Returns the value that exists at C<$path>. C<$path> is translated into hash keys, and is separated by C</>.
 
-B<C<$self->data>>
+B<C<$self-E<gt>data>>
 
 Returns the entire hash B<after> all config files have been read.
 
@@ -245,10 +245,8 @@ And then any setting that exists in C<data> that has not yet been set will be se
 
     my $config->new(data => { hello => 'world', can => { find => ['array', 'refs'] });
 
-    # { hello => 'world', can => { find => ['array', 'refs'] }
+    # $hash becomes { hello => 'world', can => { find => ['array', 'refs'] }
     my $hash = $config->data;
-
-    # $hash is { hello => 'world', can => { find => ['array', 'refs'] }
     
     # prints 'refs';
     print $config->get('can/find')->[1];
